@@ -38,7 +38,7 @@
 ;;; Lexicon
 (lex.create "spanish")
 (lex.set.phoneset "spanish")
-(lex.set.lts.method 'function) 
+(lex.set.lts.method 'spanish_lts) 
 (lex.set.lts.ruleset 'spanish)
 
 ;;; This which just have to be in the lexicon
@@ -734,7 +734,7 @@ this can't use the builtin downcase function."
 
 (define (spanish_tosyl_brackets phones)
    "(spanish_tosyl_brackets phones)
-Takes a list of phones containing - as syllable boundary.  COnstruct the
+Takes a list of phones containing - as syllable boundary.  Construct the
 Festival bracket structure."
  (let ((syl nil) (syls nil) (p phones) (stress 0))
     (while p
